"""Dispatch report requested by the user"""
import logging
from pathlib import Path
from typing import Dict

from ws_metrics.reporting.generate_report import Report

from ws_metrics.enums import ReportEnum


class DispatchReports:
    def __init__(self):
        self.logger = logging.getLogger("ws_metrics")

    def write_report(self, report_type: ReportEnum, data: Dict) -> Report:
        """
        Create a metrics report for the given type with the provided data

        :param report_type:
        :param data:
        :return: a metrics report
        """
        self.logger.info(f"Rendering {report_type.name} Report ...")
        return Report(report_type, data)

    def dispatch_file_to_user(self, report: Report, path: Path = None):
        """
        Write the metrics report to a file. If path is specified write to the provided path.

        :param report:
        :param path:
        :return:
        """
        self.logger.info(f"Writing {ReportEnum(report.type).title} to file...")
        if path is not None:
            name = path / report.name
        else:
            name = report.name

        r = open(name, "w+")
        r.write(report.file.content)
        r.close()

    @staticmethod
    def dispatch_data_to_terminal(report: Report):
        """
        Write the metrics report to the terminal

        :param report:
        :return:
        """
        print(report.file.content)
